import md5 from './md5'
import config from './config';

const getRandomNumber = (minNum = 1000000000, maxNum = 99999999999999) => parseInt(Math.random() * (maxNum - minNum + 1) + minNum, 10);

/**
 * 
 * @param {微信支付签名} params 
 * @param {*} key 
 */
function wxPaySign(params, key) {
    const paramsArr = Object.keys(params);
    paramsArr.sort();
    const stringArr = []
    paramsArr.map(key => {
        stringArr.push(key + '=' + params[key]);
    })
    // 最后加上 商户Key
    let paramStr = stringArr.join('&');
    paramStr = paramStr+key;
    return md5.md5(paramStr).toString().toLowerCase();
}

/**
 * 生成订单号
 * @param {订单号前缀} str 
 */
function getOrderNo(str) {
    let outTradeNo = "";  //订单号
    for (var i = 0; i < 6; i++) //6位随机数，用以加在时间戳后面。
    {
        outTradeNo += Math.floor(Math.random() * 10);
    }
    outTradeNo = str + new Date().getTime() + outTradeNo;  //时间戳，用来生成订单号。
    return outTradeNo;
}

/**
 * 
 * @param {金额} long_data 
 * @param { 可选,格式化金额精度, 即小数点位数. 如: 3 标示保留小数点后三位, 默认为2位} length 
 */
function formatMoney(long_data, length) {
    length = length > 0 && length <= 20 ? length : 2;
    long_data = parseFloat((long_data + "").replace(/[^\d\.-]/g, "")).toFixed(length) + "";
    let l = long_data.split(".")[0].split("").reverse();
    let r = long_data.split(".")[1];
    let t = "";
    for (let i = 0; i < l.length; i++) {
        t += l[i] + ((i + 1) % 3 == 0 && (i + 1) != l.length ? "," : "");
    }
    return t.split("").reverse().join("") + "." + r;
}


/**
 * 发起小程序支付
 */
function toPay(trade_order_id,total_fee,title,notify_url,callback) {
    //需要加密的参数
    let data = {
        version: '1.1',
        appid: config.appid,// 这是虎皮椒的APPID
        trade_order_id: trade_order_id,
        total_fee: total_fee/100,
        title: title,
        notify_url: notify_url,
        time:Math.round(new Date() / 1000),
        nonce_str: getRandomNumber(),
        type: "JSAPI",
        wap_url: 'https://api.xunhupay.com'//填写支付网关
    }
    let sign = wxPaySign(data, config.secret);
    console.log(data);
    //最后我们把签名加入进去
    data.hash = sign;

    //下面开始执行小程序支付
    //支付流程：小程序A 点击付款->跳转到 “迅虎支付” 小程序 -> 自动发起微信支付 ->支付成功后携带支付结果返回小程序A

    wx.navigateToMiniProgram({
        appId: 'wx2574b5c5ee8da56b',//支付网关为：https://api.xunhupay.com 跳转小程序APPID：wx2574b5c5ee8da56b，其他支付网关跳转小程序APPID：wx402faa5bd5eda155
        path: 'pages/hpj_cashier/cashier',//支付页面 固定值 不可修改
        extraData: data,//携带的参数 参考API文档
        success(res) {
            callback(res);
        }, fail(res) {
            callback(res);
        }
    });
}


/**
 * 暴露方法外部调用
 */
export default {
    "wxPaySign": wxPaySign,
    "getOrderNo": getOrderNo,
    "formatMoney": formatMoney,
    "toPay":toPay
}